========
evengsdk
========


.. image:: https://img.shields.io/pypi/v/evengsdk.svg
        :target: https://pypi.python.org/pypi/evengsdk

.. image:: https://img.shields.io/travis/ttafsir/evengsdk.svg
        :target: https://travis-ci.com/ttafsir/evengsdk

.. image:: https://readthedocs.org/projects/evengsdk/badge/?version=latest
        :target: https://evengsdk.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/ttafsir/evengsdk/shield.svg
     :target: https://pyup.io/repos/github/ttafsir/evengsdk/
     :alt: Updates



Python SDK and command line utilities to work with the EVE-NG REST API


* Free software: MIT license
* Documentation: https://evengsdk.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
